@@ -1,5 +1,5 @@
 # Copyright (c) 2004, 2005 Anders Ard
-## $Id: DataBase.pm,v 1.4 2006/06/01 11:31:34 anders Exp $
+## $Id: DataBase.pm 286 2008-10-13 09:13:26Z it-aar $
 
 # 
 # See the file LICENCE included in the distribution.
@@ -8,6 +8,8 @@ package Combine::DataBase;
 
 use strict;
 use Combine::MySQLhdb;
+use Digest::MD5;
+use Encode qw(encode_utf8);
 
 sub new { 
     my ($class, $xwi, $sv, $loghandle) = @_;
@@ -29,10 +31,10 @@ sub delete {
     return undef unless ref $xwi;
     
     my $urlid = $xwi->urlid;
-    my ($recordid) = $self->{databasehandle}->selectrow_array(
-              qq{SELECT recordid FROM recordurl WHERE urlid=$urlid;}); #Only one
+    my ($recordid, $md5) = $self->{databasehandle}->selectrow_array(
+              qq{SELECT recordid,md5 FROM recordurl WHERE urlid=$urlid;}); #Only one
     return if !defined($recordid);
-    $self->{'loghandle'}->say("DataBase::delete $urlid, $recordid;");
+    $self->{'loghandle'}->say("DataBase::delete $urlid, $recordid, $md5;");
 #LOCK recordurl - needed?
     $self->{databasehandle}->prepare(qq{LOCK TABLES recordurl WRITE;})->execute();
     #delete URL from recordurl
@@ -41,7 +43,7 @@ sub delete {
               qq{SELECT recordid FROM recordurl WHERE recordid=$recordid LIMIT 1;});
 #UNLOCK recordurl - needed?
     $self->{databasehandle}->prepare(qq{UNLOCK TABLES;})->execute();
-    if ( !defined($ant) || ($ant == 0) ) { Combine::MySQLhdb::DeleteKey($recordid); } #Should handle del's of non-existing recs
+    if ( !defined($ant) || ($ant == 0) ) { Combine::MySQLhdb::DeleteKey($recordid,$md5); } #Should handle del's of non-existing recs
 
     $xwi->nofollow("true"); #?? check??
 }
@@ -52,7 +54,23 @@ sub insert {
     return undef unless ref $xwi;
 
     my $urlid = $xwi->urlid;
-    my $md5 = $xwi->md5;
+##    my $md5 = $xwi->md5;
+
+    my $md5D = new Digest::MD5;
+    $md5D->reset;
+    if ( length($xwi->text) > 0 ) {
+	my $text = ${$xwi->text};
+	$text =~ s/[\s\n\r]+//g;
+	$md5D->add(encode_utf8($text)); #use only visible text without whitespace
+    } else {
+	$md5D->add($xwi->url);
+	$md5D->add($xwi->type());
+    }
+    $_ = $md5D->hexdigest;
+    tr/a-z/A-Z/;
+    $xwi->md5($_);
+    my $md5 = $_;
+
     $self->{'loghandle'}->say("DataBase::insert $urlid, $md5;");
 
     #actions according the following truth table based presence in recordurl
@@ -107,7 +125,7 @@ sub insert {
 	          qq{SELECT recordid FROM recordurl WHERE recordid=$oldrecordid LIMIT 1;}); #Outside LOCK?
 	if ( ! defined($ant) ) { $ant = 0; }
 	$self->{'loghandle'}->say("DataBase::DelURL case 2: $oldrecordid; $ant;; $existrecordid; $existurlid; $oldmd5;");
-	if ( $ant == 0 ) { Combine::MySQLhdb::DeleteKey($oldrecordid); }
+	if ( $ant == 0 ) { Combine::MySQLhdb::DeleteKey($oldrecordid, $oldmd5); }
 
 #CASE 3
     } elsif ( $existrecordid && ! $existurlid ) {
@@ -135,7 +153,7 @@ sub insert {
               qq{SELECT recordid FROM recordurl WHERE recordid=$oldrecordid LIMIT 1;});
 	if ( ! defined($ant) ) { $ant = 0; }
 	$self->{'loghandle'}->say("DataBase::DelURL $oldrecordid; $ant;");
-	if ( $ant == 0 ) { Combine::MySQLhdb::DeleteKey($oldrecordid); }
+	if ( $ant == 0 ) { Combine::MySQLhdb::DeleteKey($oldrecordid, $oldmd5); }
 	my ($recordid) = $self->{databasehandle}->selectrow_array(
               qq{SELECT recordid FROM recordurl WHERE urlid=$urlid;});
 	$xwi->recordid($recordid);
