@@ -52,7 +52,7 @@ sub Write {
     my $title = $xwi->title;
 #checkedDate is inserted/updated in DataBase.pm and harvpars.pl
     my $modifiedDate = $xwi->modifiedDate;
-#    if ( ! $modifiedDate) { $modifiedDate = $checkedDate; }
+    if ( ! $modifiedDate) { $modifiedDate = $xwi->checkedDate; }
     my $expiryDate = $xwi->expiryDate;
 #    if ($expiryDate) { $expiryDate = str2time($expiryDate) ; }
 #    else { $expiryDate = 'NULL'; }
@@ -127,7 +127,10 @@ sub Write {
 		    ($netlocid,$urlid) = $lsth->fetchrow_array;
 		    if ( !defined($urlid) ) {
 			$sv->prepare(qq{INSERT IGNORE INTO netlocs SET netlocstr=?;})->execute($netlocstr);
-			($netlocid) =  $sv->selectrow_array(qq{SELECT netlocid FROM netlocs WHERE netlocstr='$netlocstr';});
+#			($netlocid) =  $sv->selectrow_array(qq{SELECT netlocid FROM netlocs WHERE netlocstr='$netlocstr';});
+			my $nlsth =  $sv->prepare(qq{SELECT netlocid FROM netlocs WHERE netlocstr=?;});
+			$nlsth->execute($netlocstr);
+			($netlocid) =  $nlsth->fetchrow_array();
 			$sv->prepare(qq{INSERT IGNORE INTO urls SET urlstr=?, netlocid=?, path=?;})->execute($urlstr,$netlocid,$path_query);
 			$lsth->execute($urlstr);
 			($netlocid,$urlid) = $lsth->fetchrow_array;
@@ -194,9 +197,12 @@ sub Write {
         $sv->prepare("INSERT INTO topic VALUES (?, ?, ?, ?, ?, ?)")->execute($recordid, Encode::encode('utf8',$cls), $absscore, $relscore, Encode::encode('utf8',$terms), $alg);
      }
     if (my $zh = Combine::Config::Get('ZebraHost')) {
-      use Combine::Zebra;
+      require Combine::Zebra;
       Combine::Zebra::update($zh,$xwi);
     }
+    if (Combine::Config::Get('MySQLfulltext')) {
+      $sv->prepare("REPLACE INTO search VALUES (?, ?)")->execute($recordid, Encode::encode('utf8',$title .' '. $ip));
+    }
 }
 
 sub Delete { #Used??
@@ -205,22 +211,30 @@ sub Delete { #Used??
 
     my $recordid = $xwi->recordid; 
 #print "MySQLhdb::DeleteMD5 $recordid\n";
-    DeleteKey($recordid);
+    DeleteKey($recordid, $xwi->md5);
 }
 
 sub DeleteKey {
-    my ($key) = @_;
+    my ($key, $md5) = @_;
     if (!defined($sv)) { Open(); } #Init $sv CHANGE?
 #OAI
      if ($doOAI) {
 #     $sv->prepare("REPLACE INTO oai SET status='deleted', recordid=?, md5=?")->execute($key,$md5);
+##FEL recurdurl updaterad i Database.pm FIX!
        $sv->prepare("REPLACE INTO oai SELECT recordid,md5,NOW(),'deleted' FROM recordurl WHERE recordid=?")->execute($key);
      }
 #OAI
 
+#Zebra
+    if (my $zh = Combine::Config::Get('ZebraHost')) {
+      require Combine::Zebra;
+      Combine::Zebra::delete($zh,$md5);
+    }
+
 #print "MySQLhdb::DeleteKey $key\n";
     my $res = $sv->do(qq{DELETE FROM hdb WHERE recordid=$key;});
     $res = $sv->do(qq{DELETE FROM html WHERE recordid=$key;});
+    $res = $sv->do(qq{DELETE FROM search WHERE recordid=$key;});
     $res = $sv->do(qq{DELETE FROM meta WHERE recordid=$key;});
     $res = $sv->do(qq{DELETE FROM analys WHERE recordid=$key});
     $res = $sv->do(qq{DELETE FROM links WHERE recordid=$key;});
@@ -259,6 +273,9 @@ sub Get {
     my $html = Encode::decode('utf8',$html1);
     $xwi->content(\$html);
 
+    my ($urlpath) = $sv->selectrow_array(qq{SELECT path FROM urls,recordurl WHERE recordid='$key' AND recordurl.urlid=urls.urlid;});
+    $xwi->urlpath($urlpath);
+
     my ($url,$anchor,$lty,$name,$value,$heading);
 #links
     my $sth = $sv->prepare(qq{SELECT urlid,netlocid,anchor,linktype from links WHERE recordid='$key';});
