@@ -1,7 +1,13 @@
-# LaTeX2HTML 2002-2-1 (1.70)
+# LaTeX2HTML 2002-2-1 (1.71)
 # Associate images original text with physical files.
 
 
+$key = q/includegraphics[height=0.3textheightwidth=0.6textwidth]{focusedrobot.eps};LFS=11;AAT/;
+$cached_env_img{$key} = q|<IMG
+ WIDTH="498" HEIGHT="344" ALIGN="BOTTOM" BORDER="0"
+ SRC="|."$dir".q|img1.png"
+ ALT="\includegraphics[height=0.3\textheight width=0.6\textwidth]{focusedrobot.eps}">|; 
+
 $key = q/includegraphics[height=0.4textheight]{Config.ps};LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
  WIDTH="621" HEIGHT="445" ALIGN="BOTTOM" BORDER="0"
@@ -16,7 +22,7 @@ $cached_env_img{$key} = q|<IMG
 
 $key = q/weight[mbox{term}_{i}];MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="107" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="108" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img10.png"
  ALT="$weight[\mbox{term}_{i}]$">|; 
 
@@ -28,31 +34,37 @@ $cached_env_img{$key} = q|<IMG
 
 $key = q/weight[mbox{location}_{j}];MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="134" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="134" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img11.png"
  ALT="$weight[\mbox{location}_{j}]$">|; 
 
+$key = q/includegraphics[width=140mmheight=90mm]{crawl.ps};LFS=11;AAT/;
+$cached_env_img{$key} = q|<IMG
+ WIDTH="727" HEIGHT="882" ALIGN="BOTTOM" BORDER="0"
+ SRC="|."$dir".q|img24.png"
+ ALT="\includegraphics[width=140mm height=90mm]{crawl.ps}">|; 
+
 $key = q/position[mbox{term}_{i}][mbox{match}_{j}];MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="181" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="181" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img16.png"
  ALT="$position[\mbox{term}_{i}][\mbox{match}_{j}]$">|; 
 
 $key = q/{displaymath}mbox{Relevance_score}={displaymath};MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="144" HEIGHT="31" BORDER="0"
+ WIDTH="143" HEIGHT="31" BORDER="0"
  SRC="|."$dir".q|img8.png"
  ALT="\begin{displaymath}\mbox{Relevance\_score} = \end{displaymath}">|; 
 
 $key = q/hits[mbox{location}_{j}][mbox{term}_{i}];MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="162" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="163" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img12.png"
  ALT="$hits[\mbox{location}_{j}][\mbox{term}_{i}]$">|; 
 
 $key = q/mbox{term}_{i};MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="45" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="46" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img13.png"
  ALT="$\mbox{term}_{i}$">|; 
 
@@ -66,8 +78,8 @@ $cached_env_img{$key} = q|<IMG
 
 $key = q/|;MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="9" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img24.png"
+ WIDTH="10" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img25.png"
  ALT="$\vert$">|; 
 
 $key = q/includegraphics[height=0.4textheight]{CrawlerSpeed.ps};LFS=11;AAT/;
@@ -78,13 +90,13 @@ $cached_env_img{$key} = q|<IMG
 
 $key = q/mbox{location}_{j};MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="71" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="72" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img14.png"
  ALT="$\mbox{location}_{j}$">|; 
 
 $key = q/proximity[mbox{term}_{i}][mbox{match}_{j}];MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="197" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="197" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img20.png"
  ALT="$proximity[\mbox{term}_{i}][\mbox{match}_{j}]$">|; 
 
@@ -96,16 +108,10 @@ $cached_env_img{$key} = q|<IMG
 
 $key = q/mbox{match}_{j};MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="58" HEIGHT="33" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="58" HEIGHT="34" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img17.png"
  ALT="$\mbox{match}_{j}$">|; 
 
-$key = q/includegraphics[height=0.3textheightwidth=0.8textwidth]{focusedrobot.eps};LFS=11;AAT/;
-$cached_env_img{$key} = q|<IMG
- WIDTH="498" HEIGHT="344" ALIGN="BOTTOM" BORDER="0"
- SRC="|."$dir".q|img1.png"
- ALT="\includegraphics[height=0.3\textheight width=0.8\textwidth]{focusedrobot.eps}">|; 
-
 $key = q/<;MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
  WIDTH="18" HEIGHT="31" ALIGN="MIDDLE" BORDER="0"
@@ -121,7 +127,7 @@ $cached_env_img{$key} = q|<IMG
 
 $key = q/backslash;MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="13" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="13" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img5.png"
  ALT="$\backslash$">|; 
 
@@ -145,7 +151,7 @@ $cached_env_img{$key} = q|<IMG
 
 $key = q/log(distance_between_components);MSF=1.6;LFS=11;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="286" HEIGHT="35" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="286" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img21.png"
  ALT="$\log(distance\_between\_components)$">|; 
 
