@@ -1,4 +1,4 @@
-# LaTeX2HTML 2002-2-1 (1.70)
+# LaTeX2HTML 2002-2-1 (1.71)
 # Associate labels original text with physical files.
 
 
@@ -6,16 +6,16 @@ $key = q/maxUrlLength/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/Actions_for_deleting_records/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$key = q/cite_International_85/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/WaitIntervalHarvesterLockNotFound/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
+$key = q/Actions_for_deleting_records/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/appendix/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalExpirationGuaranteed/;
@@ -26,74 +26,38 @@ $key = q/Password/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/crawlspeed/;
-$external_labels{$key} = "$URL/" . q|node8.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/autoclasseval/;
-$external_labels{$key} = "$URL/" . q|node7.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/url/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/Actions_for_sanity_controlls/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/configuration/;
-$external_labels{$key} = "$URL/" . q|node5.html|; 
+$key = q/topicfocus/;
+$external_labels{$key} = "$URL/" . q|node4.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/load/;
 $external_labels{$key} = "$URL/" . q|node4.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/Loglev/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/HarvesterMaxMissions/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/doOAI/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/extmods/;
-$external_labels{$key} = "$URL/" . q|node14.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/Action_all/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$key = q/analysis/;
+$external_labels{$key} = "$URL/" . q|node6.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_controlling_scheduling_of_URLs/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/comp/;
 $external_labels{$key} = "$URL/" . q|node9.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/AutoRecycleLinks/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
+$key = q/heading_reset_heading_rewind_heading_add_heading_get_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockUnavailable/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/crawl/;
-$external_labels{$key} = "$URL/" . q|node4.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/Actions_starting_killing_crawlers/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/SummaryLength/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
@@ -102,72 +66,52 @@ $key = q/SdqRetries/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/urlfilt/;
-$external_labels{$key} = "$URL/" . q|node6.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/Actions_listing_statistics/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/converters/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
+$key = q/crawlstrategy/;
+$external_labels{$key} = "$URL/" . q|node8.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/operation/;
 $external_labels{$key} = "$URL/" . q|node6.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/pos/;
-$external_labels{$key} = "$URL/" . q|node6.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/combinearch/;
 $external_labels{$key} = "$URL/" . q|node6.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/WaitIntervalRrdLockSuccess/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/NAME/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/cite_ardo05:_ECDL/;
-$external_labels{$key} = "$URL/" . q|node10.html|; 
+$key = q/OPTIONS_AND_ARGUMENTS/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/useTidy/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/OPTIONS_AND_ARGUMENTS/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$key = q/cite_ardo05:_ECDL/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/std/;
-$external_labels{$key} = "$URL/" . q|node6.html|; 
+$key = q/robot_reset_robot_rewind_robot_add_robot_get_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/configDir/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/Misc_actions/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$key = q/Actions_exporting_link_data/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/INTRODUCTION/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockRobotRules/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/INTRODUCTION/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/gory/;
-$external_labels{$key} = "$URL/" . q|node11.html|; 
+$key = q/cite_Bang_etal_06/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/MySQLhandle/;
@@ -175,37 +119,29 @@ $external_labels{$key} = "$URL/" . q|node13.html|;
 $noresave{$key} = "$nosave";
 
 $key = q/SYNOPSIS/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/gettingstarted/;
-$external_labels{$key} = "$URL/" . q|node4.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/exclude/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/LICENSE/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$key = q/manpages/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/sqlstruct/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/cite_GolubChall/;
-$external_labels{$key} = "$URL/" . q|node10.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/Operator-Email/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/UserAgentFollowRedirects/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
+$key = q/domainfocus/;
+$external_labels{$key} = "$URL/" . q|node4.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/_add/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
 $key = q/autoclass/;
 $external_labels{$key} = "$URL/" . q|node6.html|; 
 $noresave{$key} = "$nosave";
@@ -223,7 +159,291 @@ $external_labels{$key} = "$URL/" . q|node6.html|;
 $noresave{$key} = "$nosave";
 
 $key = q/SEE_ALSO/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Hjorland06/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Garces_etal_06/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/AUTHOR/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/WaitIntervalRrdLockNotFound/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/overview/;
+$external_labels{$key} = "$URL/" . q|node3.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/link_reset_link_rewind_link_add_link_get_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/DESCRIPTION/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/UserAgentGetIfModifiedSince/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/distr/;
+$external_labels{$key} = "$URL/" . q|node4.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/classifyPlugInTemplate/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_ardo06:_ECDL/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/BUGS/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/AUTHOR_Anders_Ardo/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/EXAMPLES/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/binext/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/topicdef/;
+$external_labels{$key} = "$URL/" . q|node6.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/topicfilter/;
+$external_labels{$key} = "$URL/" . q|node6.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Olson_01/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_GolubRole/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/httpProxy/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/relTextPlugin/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/doCheckRecord/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Chen_Dumais_2000/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/extractLinksFromText/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Actions_calculating_variants_of_PageRank/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/allow/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/WaitIntervalHarvesterLockNotFound/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/autoclasseval/;
+$external_labels{$key} = "$URL/" . q|node7.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/crawlspeed/;
+$external_labels{$key} = "$URL/" . q|node8.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/url/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/configuration/;
+$external_labels{$key} = "$URL/" . q|node5.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Loglev/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Sebastiani_02/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/HarvesterMaxMissions/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/url_remove_url_reset_url_rewind_url_add_url_get_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/doOAI/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/extmods/;
+$external_labels{$key} = "$URL/" . q|node14.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Action_all/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/AutoRecycleLinks/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Rafael06/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/crawl/;
+$external_labels{$key} = "$URL/" . q|node4.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Medelyan_06/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Actions_starting_killing_crawlers/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/urlfilt/;
+$external_labels{$key} = "$URL/" . q|node6.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Actions_listing_statistics/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/xmeta_reset_xmeta_rewind_xmeta_add_xmeta_get_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/speedup/;
+$external_labels{$key} = "$URL/" . q|node8.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/METHODS/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/pos/;
+$external_labels{$key} = "$URL/" . q|node6.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/slowcrawl/;
+$external_labels{$key} = "$URL/" . q|node12.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/converters/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Lancaster_03/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/WaitIntervalRrdLockSuccess/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/NAME/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/faq/;
+$external_labels{$key} = "$URL/" . q|node12.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/std/;
+$external_labels{$key} = "$URL/" . q|node6.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Misc_actions/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/gory/;
+$external_labels{$key} = "$URL/" . q|node11.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/SVMmodel/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Yang_99/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/meta_reset_meta_rewind_meta_add_meta_get_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/_get/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/analysePlugin/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/new_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/gettingstarted/;
+$external_labels{$key} = "$URL/" . q|node4.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/LICENSE/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/exclude/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_GolubChall/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Operator-Email/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_1Ingwersen_05/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/XXX_val_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/classifyPlugIn/;
@@ -238,50 +458,34 @@ $key = q/saveHTML/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/AUTHOR/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$key = q/cite_Golub_Review/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/moddep/;
 $external_labels{$key} = "$URL/" . q|node14.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/cite_Golub_Review/;
-$external_labels{$key} = "$URL/" . q|node10.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/WaitIntervalRrdLockNotFound/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/serveralias/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/WaitIntervalRrdLockDefault/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/HarvestRetries/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/overview/;
-$external_labels{$key} = "$URL/" . q|node3.html|; 
+$key = q/WaitIntervalRrdLockDefault/;
+$external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/UAtimeout/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/UserAgentGetIfModifiedSince/;
+$key = q/MySQLfulltext/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/DESCRIPTION/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/baseConfigDir/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
@@ -295,29 +499,21 @@ $external_labels{$key} = "$URL/" . q|node13.html|;
 $noresave{$key} = "$nosave";
 
 $key = q/COPYRIGHT_AND_LICENSE/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/distr/;
-$external_labels{$key} = "$URL/" . q|node4.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/sessionids/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/classifyPlugInTemplate/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$key = q/_reset_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/cite_ardo99:_online99/;
 $external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/cite_ardo06:_ECDL/;
-$external_labels{$key} = "$URL/" . q|node10.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/termlist/;
 $external_labels{$key} = "$URL/" . q|node6.html|; 
 $noresave{$key} = "$nosave";
@@ -327,35 +523,15 @@ $external_labels{$key} = "$URL/" . q|node13.html|;
 $noresave{$key} = "$nosave";
 
 $key = q/InstTest/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/BUGS/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/topicfilter/;
-$external_labels{$key} = "$URL/" . q|node6.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/topicdef/;
-$external_labels{$key} = "$URL/" . q|node6.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/binext/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_loading_or_recycling_URLs_for_crawling/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/EXAMPLES/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/AUTHOR_Anders_Ardo/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/LogHandle/;
@@ -363,66 +539,62 @@ $external_labels{$key} = "$URL/" . q|node13.html|;
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_handling_server_aliases/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
-$noresave{$key} = "$nosave";
-
-$key = q/cite_GolubRole/;
-$external_labels{$key} = "$URL/" . q|node10.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalSchedulerGetJcf/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/httpProxy/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/debian/;
 $external_labels{$key} = "$URL/" . q|node4.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/doCheckRecord/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
-$noresave{$key} = "$nosave";
-
 $key = q/WaitIntervalHarvesterLockSuccess/;
 $external_labels{$key} = "$URL/" . q|node13.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/extractLinksFromText/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
+$key = q/_rewind_/;
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Svenonius_2000/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/conffiles/;
-$external_labels{$key} = "$URL/" . q|node15.html|; 
+$external_labels{$key} = "$URL/" . q|node16.html|; 
+$noresave{$key} = "$nosave";
+
+$key = q/cite_Lewis_etal_04/;
+$external_labels{$key} = "$URL/" . q|node10.html|; 
 $noresave{$key} = "$nosave";
 
 $key = q/config/;
 $external_labels{$key} = "$URL/" . q|node8.html|; 
 $noresave{$key} = "$nosave";
 
-$key = q/allow/;
-$external_labels{$key} = "$URL/" . q|node13.html|; 
+$key = q/performance/;
+$external_labels{$key} = "$URL/" . q|node8.html|; 
 $noresave{$key} = "$nosave";
 
 1;
 
 
-# LaTeX2HTML 2002-2-1 (1.70)
+# LaTeX2HTML 2002-2-1 (1.71)
 # labels from external_latex_labels array.
 
 
 $key = q/maxUrlLength/;
-$external_latex_labels{$key} = q|9.1.14|; 
+$external_latex_labels{$key} = q|9.1.15|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_deleting_records/;
-$external_latex_labels{$key} = q|A.5.5|; 
+$external_latex_labels{$key} = q|A.5.7|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockNotFound/;
-$external_latex_labels{$key} = q|9.1.27|; 
+$external_latex_labels{$key} = q|9.1.31|; 
 $noresave{$key} = "$nosave";
 
 $key = q/appendix/;
@@ -430,11 +602,11 @@ $external_latex_labels{$key} = q|A|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalExpirationGuaranteed/;
-$external_latex_labels{$key} = q|9.1.26|; 
+$external_latex_labels{$key} = q|9.1.30|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Password/;
-$external_latex_labels{$key} = q|9.1.18|; 
+$external_latex_labels{$key} = q|9.1.20|; 
 $noresave{$key} = "$nosave";
 
 $key = q/crawlspeed/;
@@ -445,12 +617,16 @@ $key = q/autoclasseval/;
 $external_latex_labels{$key} = q|5|; 
 $noresave{$key} = "$nosave";
 
+$key = q/topicfocus/;
+$external_latex_labels{$key} = q|2.4.3|; 
+$noresave{$key} = "$nosave";
+
 $key = q/url/;
 $external_latex_labels{$key} = q|9.2.7|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_sanity_controlls/;
-$external_latex_labels{$key} = q|A.5.5|; 
+$external_latex_labels{$key} = q|A.5.7|; 
 $noresave{$key} = "$nosave";
 
 $key = q/configuration/;
@@ -462,15 +638,19 @@ $external_latex_labels{$key} = q|2|;
 $noresave{$key} = "$nosave";
 
 $key = q/Loglev/;
-$external_latex_labels{$key} = q|9.1.13|; 
+$external_latex_labels{$key} = q|9.1.14|; 
 $noresave{$key} = "$nosave";
 
 $key = q/HarvesterMaxMissions/;
-$external_latex_labels{$key} = q|9.1.9|; 
+$external_latex_labels{$key} = q|9.1.10|; 
+$noresave{$key} = "$nosave";
+
+$key = q/url_remove_url_reset_url_rewind_url_add_url_get_/;
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/doOAI/;
-$external_latex_labels{$key} = q|9.1.7|; 
+$external_latex_labels{$key} = q|9.1.8|; 
 $noresave{$key} = "$nosave";
 
 $key = q/extmods/;
@@ -478,11 +658,15 @@ $external_latex_labels{$key} = q|10.3|;
 $noresave{$key} = "$nosave";
 
 $key = q/Action_all/;
-$external_latex_labels{$key} = q|A.5.5|; 
+$external_latex_labels{$key} = q|A.5.7|; 
+$noresave{$key} = "$nosave";
+
+$key = q/analysis/;
+$external_latex_labels{$key} = q|4.8|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_controlling_scheduling_of_URLs/;
-$external_latex_labels{$key} = q|A.5.1|; 
+$external_latex_labels{$key} = q|A.5.2|; 
 $noresave{$key} = "$nosave";
 
 $key = q/comp/;
@@ -490,11 +674,15 @@ $external_latex_labels{$key} = q|7|;
 $noresave{$key} = "$nosave";
 
 $key = q/AutoRecycleLinks/;
-$external_latex_labels{$key} = q|9.1.1|; 
+$external_latex_labels{$key} = q|9.1.2|; 
+$noresave{$key} = "$nosave";
+
+$key = q/heading_reset_heading_rewind_heading_add_heading_get_/;
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockUnavailable/;
-$external_latex_labels{$key} = q|9.1.31|; 
+$external_latex_labels{$key} = q|9.1.35|; 
 $noresave{$key} = "$nosave";
 
 $key = q/crawl/;
@@ -502,15 +690,15 @@ $external_latex_labels{$key} = q|3|;
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_starting_killing_crawlers/;
-$external_latex_labels{$key} = q|A.5.1|; 
+$external_latex_labels{$key} = q|A.5.2|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SummaryLength/;
-$external_latex_labels{$key} = q|9.1.21|; 
+$external_latex_labels{$key} = q|9.1.24|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SdqRetries/;
-$external_latex_labels{$key} = q|9.1.20|; 
+$external_latex_labels{$key} = q|9.1.23|; 
 $noresave{$key} = "$nosave";
 
 $key = q/urlfilt/;
@@ -518,19 +706,39 @@ $external_latex_labels{$key} = q|4.3|;
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_listing_statistics/;
-$external_latex_labels{$key} = q|A.5.5|; 
+$external_latex_labels{$key} = q|A.5.7|; 
 $noresave{$key} = "$nosave";
 
-$key = q/converters/;
-$external_latex_labels{$key} = q|9.2.3|; 
+$key = q/crawlstrategy/;
+$external_latex_labels{$key} = q|6|; 
+$noresave{$key} = "$nosave";
+
+$key = q/speedup/;
+$external_latex_labels{$key} = q|1|; 
+$noresave{$key} = "$nosave";
+
+$key = q/xmeta_reset_xmeta_rewind_xmeta_add_xmeta_get_/;
+$external_latex_labels{$key} = q|A.5.11|; 
+$noresave{$key} = "$nosave";
+
+$key = q/METHODS/;
+$external_latex_labels{$key} = q|A.5.11|; 
+$noresave{$key} = "$nosave";
+
+$key = q/slowcrawl/;
+$external_latex_labels{$key} = q|7|; 
+$noresave{$key} = "$nosave";
+
+$key = q/pos/;
+$external_latex_labels{$key} = q|4.5.5|; 
 $noresave{$key} = "$nosave";
 
 $key = q/operation/;
 $external_latex_labels{$key} = q|4|; 
 $noresave{$key} = "$nosave";
 
-$key = q/pos/;
-$external_latex_labels{$key} = q|4.5.5|; 
+$key = q/converters/;
+$external_latex_labels{$key} = q|9.2.3|; 
 $noresave{$key} = "$nosave";
 
 $key = q/combinearch/;
@@ -538,39 +746,51 @@ $external_latex_labels{$key} = q|2|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalRrdLockSuccess/;
-$external_latex_labels{$key} = q|9.1.35|; 
+$external_latex_labels{$key} = q|9.1.39|; 
 $noresave{$key} = "$nosave";
 
 $key = q/NAME/;
-$external_latex_labels{$key} = q|A.5.15|; 
+$external_latex_labels{$key} = q|A.5.20|; 
+$noresave{$key} = "$nosave";
+
+$key = q/faq/;
+$external_latex_labels{$key} = q|8|; 
 $noresave{$key} = "$nosave";
 
 $key = q/useTidy/;
-$external_latex_labels{$key} = q|9.1.25|; 
+$external_latex_labels{$key} = q|9.1.29|; 
 $noresave{$key} = "$nosave";
 
 $key = q/OPTIONS_AND_ARGUMENTS/;
-$external_latex_labels{$key} = q|A.5.5|; 
+$external_latex_labels{$key} = q|A.5.8|; 
 $noresave{$key} = "$nosave";
 
-$key = q/configDir/;
-$external_latex_labels{$key} = q|9.1.4|; 
+$key = q/robot_reset_robot_rewind_robot_add_robot_get_/;
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/std/;
 $external_latex_labels{$key} = q|4.5.4|; 
 $noresave{$key} = "$nosave";
 
+$key = q/configDir/;
+$external_latex_labels{$key} = q|9.1.5|; 
+$noresave{$key} = "$nosave";
+
 $key = q/Misc_actions/;
-$external_latex_labels{$key} = q|A.5.1|; 
+$external_latex_labels{$key} = q|A.5.2|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Actions_exporting_link_data/;
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockRobotRules/;
-$external_latex_labels{$key} = q|9.1.29|; 
+$external_latex_labels{$key} = q|9.1.33|; 
 $noresave{$key} = "$nosave";
 
 $key = q/INTRODUCTION/;
-$external_latex_labels{$key} = q|A.5.15|; 
+$external_latex_labels{$key} = q|A.5.10|; 
 $noresave{$key} = "$nosave";
 
 $key = q/gory/;
@@ -578,11 +798,31 @@ $external_latex_labels{$key} = q|II|;
 $noresave{$key} = "$nosave";
 
 $key = q/MySQLhandle/;
-$external_latex_labels{$key} = q|9.1.16|; 
+$external_latex_labels{$key} = q|9.1.18|; 
+$noresave{$key} = "$nosave";
+
+$key = q/SVMmodel/;
+$external_latex_labels{$key} = q|9.1.25|; 
+$noresave{$key} = "$nosave";
+
+$key = q/analysePlugin/;
+$external_latex_labels{$key} = q|9.1.1|; 
 $noresave{$key} = "$nosave";
 
 $key = q/SYNOPSIS/;
-$external_latex_labels{$key} = q|A.5.5|; 
+$external_latex_labels{$key} = q|A.5.11|; 
+$noresave{$key} = "$nosave";
+
+$key = q/_get/;
+$external_latex_labels{$key} = q|A.5.11|; 
+$noresave{$key} = "$nosave";
+
+$key = q/meta_reset_meta_rewind_meta_add_meta_get_/;
+$external_latex_labels{$key} = q|A.5.11|; 
+$noresave{$key} = "$nosave";
+
+$key = q/new_/;
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/gettingstarted/;
@@ -594,27 +834,43 @@ $external_latex_labels{$key} = q|9.2.4|;
 $noresave{$key} = "$nosave";
 
 $key = q/LICENSE/;
-$external_latex_labels{$key} = q|A.5.8|; 
+$external_latex_labels{$key} = q|A.5.18|; 
+$noresave{$key} = "$nosave";
+
+$key = q/UserAgentFollowRedirects/;
+$external_latex_labels{$key} = q|9.1.27|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Operator-Email/;
+$external_latex_labels{$key} = q|9.1.19|; 
+$noresave{$key} = "$nosave";
+
+$key = q/domainfocus/;
+$external_latex_labels{$key} = q|2.4.2|; 
+$noresave{$key} = "$nosave";
+
+$key = q/manpages/;
+$external_latex_labels{$key} = q|A.5|; 
 $noresave{$key} = "$nosave";
 
 $key = q/sqlstruct/;
 $external_latex_labels{$key} = q|A.4|; 
 $noresave{$key} = "$nosave";
 
-$key = q/Operator-Email/;
-$external_latex_labels{$key} = q|9.1.17|; 
-$noresave{$key} = "$nosave";
-
-$key = q/UserAgentFollowRedirects/;
-$external_latex_labels{$key} = q|9.1.23|; 
+$key = q/_add/;
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/autoclass/;
 $external_latex_labels{$key} = q|4.5|; 
 $noresave{$key} = "$nosave";
 
+$key = q/XXX_val_/;
+$external_latex_labels{$key} = q|A.5.11|; 
+$noresave{$key} = "$nosave";
+
 $key = q/MySQLdatabase/;
-$external_latex_labels{$key} = q|9.1.15|; 
+$external_latex_labels{$key} = q|9.1.16|; 
 $noresave{$key} = "$nosave";
 
 $key = q/sched/;
@@ -622,27 +878,27 @@ $external_latex_labels{$key} = q|4.4|;
 $noresave{$key} = "$nosave";
 
 $key = q/ZebraHost/;
-$external_latex_labels{$key} = q|9.1.37|; 
-$noresave{$key} = "$nosave";
-
-$key = q/SEE_ALSO/;
-$external_latex_labels{$key} = q|A.5.5|; 
+$external_latex_labels{$key} = q|9.1.41|; 
 $noresave{$key} = "$nosave";
 
 $key = q/classifyPlugIn/;
-$external_latex_labels{$key} = q|9.1.3|; 
+$external_latex_labels{$key} = q|9.1.4|; 
+$noresave{$key} = "$nosave";
+
+$key = q/SEE_ALSO/;
+$external_latex_labels{$key} = q|A.5.11|; 
+$noresave{$key} = "$nosave";
+
+$key = q/saveHTML/;
+$external_latex_labels{$key} = q|9.1.22|; 
 $noresave{$key} = "$nosave";
 
 $key = q/configvars/;
 $external_latex_labels{$key} = q|9|; 
 $noresave{$key} = "$nosave";
 
-$key = q/saveHTML/;
-$external_latex_labels{$key} = q|9.1.19|; 
-$noresave{$key} = "$nosave";
-
 $key = q/AUTHOR/;
-$external_latex_labels{$key} = q|A.5.14|; 
+$external_latex_labels{$key} = q|A.5.20|; 
 $noresave{$key} = "$nosave";
 
 $key = q/moddep/;
@@ -650,7 +906,7 @@ $external_latex_labels{$key} = q|10|;
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalRrdLockNotFound/;
-$external_latex_labels{$key} = q|9.1.34|; 
+$external_latex_labels{$key} = q|9.1.38|; 
 $noresave{$key} = "$nosave";
 
 $key = q/serveralias/;
@@ -658,11 +914,11 @@ $external_latex_labels{$key} = q|9.2.5|;
 $noresave{$key} = "$nosave";
 
 $key = q/HarvestRetries/;
-$external_latex_labels{$key} = q|9.1.10|; 
+$external_latex_labels{$key} = q|9.1.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalRrdLockDefault/;
-$external_latex_labels{$key} = q|9.1.33|; 
+$external_latex_labels{$key} = q|9.1.37|; 
 $noresave{$key} = "$nosave";
 
 $key = q/overview/;
@@ -670,51 +926,63 @@ $external_latex_labels{$key} = q|1|;
 $noresave{$key} = "$nosave";
 
 $key = q/UAtimeout/;
-$external_latex_labels{$key} = q|9.1.22|; 
+$external_latex_labels{$key} = q|9.1.26|; 
+$noresave{$key} = "$nosave";
+
+$key = q/MySQLfulltext/;
+$external_latex_labels{$key} = q|9.1.17|; 
+$noresave{$key} = "$nosave";
+
+$key = q/link_reset_link_rewind_link_add_link_get_/;
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/UserAgentGetIfModifiedSince/;
-$external_latex_labels{$key} = q|9.1.24|; 
-$noresave{$key} = "$nosave";
-
-$key = q/DESCRIPTION/;
-$external_latex_labels{$key} = q|A.5.14|; 
-$noresave{$key} = "$nosave";
-
-$key = q/baseConfigDir/;
-$external_latex_labels{$key} = q|9.1.2|; 
-$noresave{$key} = "$nosave";
-
-$key = q/WaitIntervalHarvesterLockNotModified/;
 $external_latex_labels{$key} = q|9.1.28|; 
 $noresave{$key} = "$nosave";
 
-$key = q/WaitIntervalHost/;
+$key = q/DESCRIPTION/;
+$external_latex_labels{$key} = q|A.5.20|; 
+$noresave{$key} = "$nosave";
+
+$key = q/baseConfigDir/;
+$external_latex_labels{$key} = q|9.1.3|; 
+$noresave{$key} = "$nosave";
+
+$key = q/WaitIntervalHarvesterLockNotModified/;
 $external_latex_labels{$key} = q|9.1.32|; 
 $noresave{$key} = "$nosave";
 
-$key = q/COPYRIGHT_AND_LICENSE/;
-$external_latex_labels{$key} = q|A.5.14|; 
+$key = q/WaitIntervalHost/;
+$external_latex_labels{$key} = q|9.1.36|; 
 $noresave{$key} = "$nosave";
 
-$key = q/sessionids/;
-$external_latex_labels{$key} = q|9.2.6|; 
+$key = q/COPYRIGHT_AND_LICENSE/;
+$external_latex_labels{$key} = q|A.5.20|; 
 $noresave{$key} = "$nosave";
 
 $key = q/distr/;
 $external_latex_labels{$key} = q|2|; 
 $noresave{$key} = "$nosave";
 
+$key = q/sessionids/;
+$external_latex_labels{$key} = q|9.2.6|; 
+$noresave{$key} = "$nosave";
+
 $key = q/classifyPlugInTemplate/;
 $external_latex_labels{$key} = q|A.2|; 
 $noresave{$key} = "$nosave";
 
+$key = q/_reset_/;
+$external_latex_labels{$key} = q|A.5.11|; 
+$noresave{$key} = "$nosave";
+
 $key = q/termlist/;
 $external_latex_labels{$key} = q|4.5.1|; 
 $noresave{$key} = "$nosave";
 
 $key = q/doAnalyse/;
-$external_latex_labels{$key} = q|9.1.5|; 
+$external_latex_labels{$key} = q|9.1.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/InstTest/;
@@ -722,11 +990,7 @@ $external_latex_labels{$key} = q|A.1|;
 $noresave{$key} = "$nosave";
 
 $key = q/BUGS/;
-$external_latex_labels{$key} = q|A.5.15|; 
-$noresave{$key} = "$nosave";
-
-$key = q/binext/;
-$external_latex_labels{$key} = q|9.2.2|; 
+$external_latex_labels{$key} = q|A.5.10|; 
 $noresave{$key} = "$nosave";
 
 $key = q/topicfilter/;
@@ -737,61 +1001,85 @@ $key = q/topicdef/;
 $external_latex_labels{$key} = q|4.5.1|; 
 $noresave{$key} = "$nosave";
 
-$key = q/Actions_loading_or_recycling_URLs_for_crawling/;
-$external_latex_labels{$key} = q|A.5.1|; 
+$key = q/binext/;
+$external_latex_labels{$key} = q|9.2.2|; 
 $noresave{$key} = "$nosave";
 
 $key = q/EXAMPLES/;
-$external_latex_labels{$key} = q|A.5.5|; 
+$external_latex_labels{$key} = q|A.5.7|; 
+$noresave{$key} = "$nosave";
+
+$key = q/Actions_loading_or_recycling_URLs_for_crawling/;
+$external_latex_labels{$key} = q|A.5.2|; 
+$noresave{$key} = "$nosave";
+
+$key = q/topic_reset_topic_rewind_topic_add_topic_get_/;
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/AUTHOR_Anders_Ardo/;
-$external_latex_labels{$key} = q|A.5.8|; 
+$external_latex_labels{$key} = q|A.5.18|; 
 $noresave{$key} = "$nosave";
 
 $key = q/LogHandle/;
-$external_latex_labels{$key} = q|9.1.12|; 
+$external_latex_labels{$key} = q|9.1.13|; 
 $noresave{$key} = "$nosave";
 
 $key = q/Actions_for_handling_server_aliases/;
-$external_latex_labels{$key} = q|A.5.5|; 
+$external_latex_labels{$key} = q|A.5.7|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalSchedulerGetJcf/;
-$external_latex_labels{$key} = q|9.1.36|; 
+$external_latex_labels{$key} = q|9.1.40|; 
 $noresave{$key} = "$nosave";
 
 $key = q/httpProxy/;
-$external_latex_labels{$key} = q|9.1.11|; 
+$external_latex_labels{$key} = q|9.1.12|; 
 $noresave{$key} = "$nosave";
 
 $key = q/debian/;
 $external_latex_labels{$key} = q|2.1.3|; 
 $noresave{$key} = "$nosave";
 
+$key = q/relTextPlugin/;
+$external_latex_labels{$key} = q|9.1.21|; 
+$noresave{$key} = "$nosave";
+
 $key = q/doCheckRecord/;
-$external_latex_labels{$key} = q|9.1.6|; 
+$external_latex_labels{$key} = q|9.1.7|; 
 $noresave{$key} = "$nosave";
 
 $key = q/WaitIntervalHarvesterLockSuccess/;
-$external_latex_labels{$key} = q|9.1.30|; 
+$external_latex_labels{$key} = q|9.1.34|; 
+$noresave{$key} = "$nosave";
+
+$key = q/_rewind_/;
+$external_latex_labels{$key} = q|A.5.11|; 
 $noresave{$key} = "$nosave";
 
 $key = q/extractLinksFromText/;
-$external_latex_labels{$key} = q|9.1.8|; 
+$external_latex_labels{$key} = q|9.1.9|; 
 $noresave{$key} = "$nosave";
 
 $key = q/conffiles/;
 $external_latex_labels{$key} = q|A.3|; 
 $noresave{$key} = "$nosave";
 
-$key = q/allow/;
-$external_latex_labels{$key} = q|9.2.1|; 
+$key = q/Actions_calculating_variants_of_PageRank/;
+$external_latex_labels{$key} = q|A.5.6|; 
 $noresave{$key} = "$nosave";
 
 $key = q/config/;
 $external_latex_labels{$key} = q|5|; 
 $noresave{$key} = "$nosave";
 
+$key = q/allow/;
+$external_latex_labels{$key} = q|9.2.1|; 
+$noresave{$key} = "$nosave";
+
+$key = q/performance/;
+$external_latex_labels{$key} = q|6|; 
+$noresave{$key} = "$nosave";
+
 1;
 
